==> valentina_0.7.47~dfsg.orig.tar.xz: valentina-v0.7.47/src/libs/vwidgets/vdecorationaligningdelegate.h <==
/************************************************************************
 **
 **  @file   vdecorationaligningdelegate.h
 **  @author Roman Telezhynskyi <dismine(at)gmail.com>
 **  @date   6 10, 2020
 **
 **  @brief
 **  @copyright
 **  This source code is part of the Valentina project, a pattern making
 **  program, whose allow create and modeling patterns of clothing.
 **  Copyright (C) 2020 Valentina project
 **  <https://gitlab.com/smart-pattern/valentina> All Rights Reserved.
 **
 **  Valentina is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation, either version 3 of the License, or
 **  (at your option) any later version.
 **
 **  Valentina is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
 **  along with Valentina.  If not, see <http://www.gnu.org/licenses/>.
 **
 *************************************************************************/
#ifndef VDECORATIONALIGNINGDELEGATE_H
#define VDECORATIONALIGNINGDELEGATE_H

#include <QStyledItemDelegate>



class VDecorationAligningDelegate : public QStyledItemDelegate
{
    Q_OBJECT

public:
    explicit VDecorationAligningDelegate(Qt::Alignment alignment, QObject *parent = nullptr);

    Qt::Alignment Alignment() const;

    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;

private:
    Q_DISABLE_COPY(VDecorationAligningDelegate)
    Qt::Alignment const m_alignment;
};

//---------------------------------------------------------------------------------------------------------------------
inline Qt::Alignment VDecorationAligningDelegate::Alignment() const
{
    return m_alignment;
}

#endif // VDECORATIONALIGNINGDELEGATE_H

==> valentina_0.7.52~dfsg.orig.tar.xz: valentina-v0.7.52/src/libs/vwidgets/vdecorationaligningdelegate.h <==
/************************************************************************
 **
 **  @file   vdecorationaligningdelegate.h
 **  @author Roman Telezhynskyi <dismine(at)gmail.com>
 **  @date   6 10, 2020
 **
 **  @brief
 **  @copyright
 **  This source code is part of the Valentina project, a pattern making
 **  program, whose allow create and modeling patterns of clothing.
 **  Copyright (C) 2020 Valentina project
 **  <https://gitlab.com/smart-pattern/valentina> All Rights Reserved.
 **
 **  Valentina is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation, either version 3 of the License, or
 **  (at your option) any later version.
 **
 **  Valentina is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
 **  along with Valentina.  If not, see <http://www.gnu.org/licenses/>.
 **
 *************************************************************************/
#ifndef VDECORATIONALIGNINGDELEGATE_H
#define VDECORATIONALIGNINGDELEGATE_H

#include <QStyledItemDelegate>

#include "../vmisc/defglobal.h"

class VDecorationAligningDelegate : public QStyledItemDelegate
{
    Q_OBJECT // NOLINT

public:
    explicit VDecorationAligningDelegate(Qt::Alignment alignment, QObject *parent = nullptr);

    Qt::Alignment Alignment() const;

    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;

private:
    // cppcheck-suppress unknownMacro
    Q_DISABLE_COPY_MOVE(VDecorationAligningDelegate) // NOLINT
    Qt::Alignment const m_alignment;
};

//---------------------------------------------------------------------------------------------------------------------
inline Qt::Alignment VDecorationAligningDelegate::Alignment() const
{
    return m_alignment;
}

#endif // VDECORATIONALIGNINGDELEGATE_H
